@@ -1,4 +1,4 @@
-# (C) Copyright 2017-2019 by Rocky Bernstein
+# (C) Copyright 2017-2020 by Rocky Bernstein
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-from xdis import PYTHON3
+from xdis import PYTHON3, PYTHON_VERSION
 import inspect, types
 
 
