@@ -43,68 +43,102 @@ from xdis.util import format_code_info
 from xdis.version import VERSION
 from xdis.op_imports import op_imports
 
+
 def get_opcode(version, is_pypy):
     # Set up disassembler with the right opcodes
     lookup = str(version)
     if is_pypy:
-        lookup += 'pypy'
+        lookup += "pypy"
     if lookup in op_imports.keys():
         return op_imports[lookup]
     if is_pypy:
-        pypy_str = ' for pypy'
+        pypy_str = " for pypy"
     else:
-        pypy_str = ''
-    raise TypeError("%s is not a Python version%s I know about" %
-                    (version, pypy_str))
+        pypy_str = ""
+    raise TypeError("%s is not a Python version%s I know about" % (version, pypy_str))
 
-def show_module_header(bytecode_version, co, timestamp, out=sys.stdout,
-                       is_pypy=False, magic_int=None,
-                       source_size=None, header=True,
-                       show_filename=True):
+
+def show_module_header(
+    bytecode_version,
+    co,
+    timestamp,
+    out=sys.stdout,
+    is_pypy=False,
+    magic_int=None,
+    source_size=None,
+    header=True,
+    show_filename=True,
+):
 
     real_out = out or sys.stdout
     if is_pypy:
-        co_pypy_str = 'PyPy '
+        co_pypy_str = "PyPy "
     else:
-        co_pypy_str = ''
+        co_pypy_str = ""
 
     if IS_PYPY:
-        run_pypy_str = 'PyPy '
+        run_pypy_str = "PyPy "
     else:
-        run_pypy_str = ''
+        run_pypy_str = ""
 
     if header:
-        magic_str = ''
+        magic_str = ""
         if magic_int:
             magic_str = str(magic_int)
-        real_out.write(('# pydisasm version %s\n# %sPython bytecode %s%s'
-                        '\n# Disassembled from %sPython %s\n') %
-                       (VERSION, co_pypy_str, bytecode_version,
-                        " (%s)" % magic_str,
-                        run_pypy_str, '\n# '.join(sys.version.split('\n'))))
+        real_out.write(
+            (
+                "# pydisasm version %s\n# %sPython bytecode %s%s"
+                "\n# Disassembled from %sPython %s\n"
+            )
+            % (
+                VERSION,
+                co_pypy_str,
+                bytecode_version,
+                " (%s)" % magic_str,
+                run_pypy_str,
+                "\n# ".join(sys.version.split("\n")),
+            )
+        )
     if timestamp > 0:
         value = datetime.datetime.fromtimestamp(timestamp)
-        real_out.write('# Timestamp in code: %d' % timestamp)
-        real_out.write(value.strftime(' (%Y-%m-%d %H:%M:%S)\n'))
+        real_out.write("# Timestamp in code: %d" % timestamp)
+        real_out.write(value.strftime(" (%Y-%m-%d %H:%M:%S)\n"))
     if source_size:
-        real_out.write('# Source code size mod 2**32: %d bytes\n' % source_size)
+        real_out.write("# Source code size mod 2**32: %d bytes\n" % source_size)
     if show_filename:
-        real_out.write('# Embedded file name: %s\n' % co.co_filename)
+        real_out.write("# Embedded file name: %s\n" % co.co_filename)
 
 
-def disco(bytecode_version, co, timestamp, out=sys.stdout,
-          is_pypy=False, magic_int=None, source_size=None,
-          header=True, asm_format=False, show_bytes=False,
-          dup_lines=False):
+def disco(
+    bytecode_version,
+    co,
+    timestamp,
+    out=sys.stdout,
+    is_pypy=False,
+    magic_int=None,
+    source_size=None,
+    header=True,
+    asm_format=False,
+    show_bytes=False,
+    dup_lines=False,
+):
     """
     diassembles and deparses a given code block 'co'
     """
 
     assert iscode(co)
 
-    show_module_header(bytecode_version, co, timestamp, out,
-                       is_pypy, magic_int, source_size, header,
-                        show_filename=False)
+    show_module_header(
+        bytecode_version,
+        co,
+        timestamp,
+        out,
+        is_pypy,
+        magic_int,
+        source_size,
+        header,
+        show_filename=False,
+    )
 
     # store final output stream for case of error
     real_out = out or sys.stdout
@@ -116,16 +150,13 @@ def disco(bytecode_version, co, timestamp, out=sys.stdout,
     opc = get_opcode(bytecode_version, is_pypy)
 
     if asm_format:
-        disco_loop_asm_format(opc, bytecode_version, co, real_out,
-                              {}, set([]))
+        disco_loop_asm_format(opc, bytecode_version, co, real_out, {}, set([]))
     else:
         queue = deque([co])
-        disco_loop(opc, bytecode_version, queue, real_out,
-                   show_bytes=show_bytes)
+        disco_loop(opc, bytecode_version, queue, real_out, show_bytes=show_bytes)
 
 
-def disco_loop(opc, version, queue, real_out, dup_lines=False,
-               show_bytes=False):
+def disco_loop(opc, version, queue, real_out, dup_lines=False, show_bytes=False):
     """Disassembles a queue of code objects. If we discover
     another code object which will be found in co_consts, we add
     the new code to the list. Note that the order of code discovery
@@ -138,7 +169,7 @@ def disco_loop(opc, version, queue, real_out, dup_lines=False,
 
     while len(queue) > 0:
         co = queue.popleft()
-        if co.co_name not in ('<module>', '?'):
+        if co.co_name not in ("<module>", "?"):
             real_out.write("\n" + format_code_info(co, version) + "\n")
 
         bytecode = Bytecode(co, opc, dup_lines=dup_lines)
@@ -150,12 +181,13 @@ def disco_loop(opc, version, queue, real_out, dup_lines=False,
             pass
         pass
 
+
 def code_uniquify(basename, co_code):
     # FIXME: better would be a hash of the co_code
     return "%s_0x%x" % (basename, id(co_code))
 
-def disco_loop_asm_format(opc, version, co, real_out,
-                          fn_name_map, all_fns):
+
+def disco_loop_asm_format(opc, version, co, real_out, fn_name_map, all_fns):
     """Produces disassembly in a format more conducive to
     automatic assembly by producing inner modules before they are
     used by outer ones. Since this is recusive, we'll
@@ -177,13 +209,14 @@ def disco_loop_asm_format(opc, version, co, real_out,
                 c_compat = code2compat(c)
             else:
                 c_compat = code3compat(c)
-            disco_loop_asm_format(opc, version, c_compat, real_out,
-                                  fn_name_map, all_fns)
+            disco_loop_asm_format(
+                opc, version, c_compat, real_out, fn_name_map, all_fns
+            )
 
             m = re.match(".* object <(.+)> at", str(c))
             if m:
                 basename = m.group(1)
-                if basename != 'module':
+                if basename != "module":
                     mapped_name = code_uniquify(basename, c.co_code)
                     c_compat.co_name = mapped_name
             c_compat.freeze()
@@ -199,7 +232,7 @@ def disco_loop_asm_format(opc, version, co, real_out,
             basename = co_name
         else:
             basename = m.group(1)
-        if basename != 'module':
+        if basename != "module":
             mapped_name = code_uniquify(basename, co.co_code)
             co_name = mapped_name
             assert mapped_name not in fn_name_map
@@ -215,14 +248,16 @@ def disco_loop_asm_format(opc, version, co, real_out,
 
     co = co.freeze()
     all_fns.add(co_name)
-    if co.co_name != '<module>' or co.co_filename:
+    if co.co_name != "<module>" or co.co_filename:
         real_out.write("\n" + format_code_info(co, version, mapped_name) + "\n")
 
     bytecode = Bytecode(co, opc, dup_lines=True)
     real_out.write(bytecode.dis(asm_format=True) + "\n")
 
-def disassemble_file(filename, outstream=sys.stdout,
-                     asm_format=False, header=False, show_bytes=False):
+
+def disassemble_file(
+    filename, outstream=sys.stdout, asm_format=False, header=False, show_bytes=False
+):
     """
     disassemble Python byte-code file (.pyc)
 
@@ -230,18 +265,36 @@ def disassemble_file(filename, outstream=sys.stdout,
     try to find the corresponding compiled object.
     """
     filename = check_object_path(filename)
-    version, timestamp, magic_int, co, is_pypy, source_size  = load_module(filename)
+    version, timestamp, magic_int, co, is_pypy, source_size = load_module(filename)
 
     if header:
-        show_module_header(version, co, timestamp, outstream,
-                           is_pypy, magic_int, source_size, show_filename=True)
+        show_module_header(
+            version,
+            co,
+            timestamp,
+            outstream,
+            is_pypy,
+            magic_int,
+            source_size,
+            show_filename=True,
+        )
 
     else:
-        disco(version, co, timestamp, outstream, is_pypy, magic_int, source_size,
-              asm_format=asm_format, show_bytes=show_bytes)
+        disco(
+            version,
+            co,
+            timestamp,
+            outstream,
+            is_pypy,
+            magic_int,
+            source_size,
+            asm_format=asm_format,
+            show_bytes=show_bytes,
+        )
     # print co.co_filename
     return filename, co, version, timestamp, magic_int
 
+
 def _test():
     """Simple test program to disassemble a file."""
     argc = len(sys.argv)
@@ -255,5 +308,6 @@ def _test():
         fn = sys.argv[1]
     disassemble_file(fn)
 
+
 if __name__ == "__main__":
     _test()
