@@ -39,7 +39,7 @@ version = 1.3
 l = locals()
 init_opdata(l, opcode_14, version)
 
-# 1.3 - 14 bytecodes differences
+# 1.3 - 1.4 bytecodes differences
 rm_op(l, "BINARY_POWER", 19)
 def_op(l, "LOAD_GLOBALS", 84)
 
@@ -49,19 +49,4 @@ opcode_arg_fmt = {"EXTENDED_ARG": format_extended_arg}
 
 finalize_opcodes(l)
 
-
-def findlinestarts(co, dup_lines=False):
-    code = co.co_code
-    n = len(code)
-    offset = 0
-    while offset < n:
-        op = code[offset]
-        offset += 1
-        if op == l["opmap"]["SET_LINENO"] and offset > 0:
-            lineno = code[offset] + code[offset + 1] * 256
-            yield (offset - 1, lineno)
-            pass
-        if op >= l["HAVE_ARGUMENT"]:
-            offset += 2
-            pass
-        pass
+findlinestarts = opcode_14.findlinestarts
