@@ -7,9 +7,15 @@ of stack usage.
 """
 
 from xdis.opcodes.base import (
-    def_op, finalize_opcodes, init_opdata,
-    jrel_op, name_op, nargs_op,
-    varargs_op, update_pj3)
+    def_op,
+    finalize_opcodes,
+    init_opdata,
+    jrel_op,
+    name_op,
+    nargs_op,
+    varargs_op,
+    update_pj3,
+)
 
 version = 3.5
 
@@ -22,17 +28,17 @@ init_opdata(l, opcode_35, version, is_pypy=True)
 
 # PyPy only
 # ----------
-def_op(l, 'FORMAT_VALUE',   155)
-def_op(l, 'BUILD_STRING',   157)
-name_op(l, 'LOOKUP_METHOD',  201,  1, 2)
-nargs_op(l, 'CALL_METHOD', 202, -1, 1)
-l['hasvargs'].append(202)
+def_op(l, "FORMAT_VALUE", 155)
+def_op(l, "BUILD_STRING", 157)
+name_op(l, "LOOKUP_METHOD", 201, 1, 2)
+nargs_op(l, "CALL_METHOD", 202, -1, 1)
+l["hasvargs"].append(202)
 
 # Used only in single-mode compilation list-comprehension generators
-varargs_op(l, 'BUILD_LIST_FROM_ARG', 203)
+varargs_op(l, "BUILD_LIST_FROM_ARG", 203)
 
 # Used only in assert statements
-jrel_op(l, 'JUMP_IF_NOT_DEBUG',      204, conditional=True)
+jrel_op(l, "JUMP_IF_NOT_DEBUG", 204, conditional=True)
 
 # There are no opcodes to remove or change.
 # If there were, they'd be listed below.
